@@ -1,4 +1,5 @@
 import os
+from pathlib import Path
 
 from PyQt5.QtWidgets import QApplication
 
@@ -10,7 +11,11 @@ def run():
     import sys
     import logging
 
-    logging.basicConfig(level=logging.DEBUG)
+    print(sys.executable)
+
+    log_file = 'dummy_autoupdate_log.txt'
+    logging.basicConfig(level=logging.DEBUG, filename=log_file)
+    print((Path(__file__).parent / log_file).resolve())
 
     qapp = QApplication([])
     window = MainWindow(__version__)
